@@ -6,27 +6,27 @@
 setGeneric(name="query",def=function(.Object, field, ...){standardGeneric("query")})
 
 
-#'@title query webdata for various fields
+#' query webdata for various fields
 #'
-#'@details a method for finding possible values for a given field
+#' a method for finding possible values for a given field
 #'
-#'@param .Object a \code{webdata}, \code{webgeom}, or \code{webprocess} object.
-#'@param field a plural parameter name for fields in .Object (e.g., 'variables', 'times')
-#'@param ... additional arguments passed to methods
-#'@return a character vector of values corresponding to the query field specified
-#'@aliases query,webdata-method  
-#'@keywords methods
-#'@examples
-#'fabric <- webdata('prism')
-#'query(fabric, 'variables')
-#'wg <- webgeom()
-#'query(wg, 'geoms')
-#'geom(wg) <- "derivative:CONUS_States"
-#'query(wg, 'attributes')
-#'attribute(wg) <- 'STATE'
-#'query(wg, 'values', rm.duplicates = TRUE)
-#'@rdname query
-#'@aliases query,webdata-method  
+#' @param .Object a \code{webdata}, \code{webgeom}, or \code{webprocess} object.
+#' @param field a plural parameter name for fields in .Object (e.g., 'variables', 'times')
+#' @param ... additional arguments passed to methods
+#' @return a character vector of values corresponding to the query field specified
+#' @aliases query,webdata-method  
+#' @keywords methods
+#' @examples
+#' fabric <- webdata('prism')
+#' query(fabric, 'variables')
+#' wg <- webgeom()
+#' query(wg, 'geoms')
+#' geom(wg) <- "derivative:CONUS_States"
+#' query(wg, 'attributes')
+#' attribute(wg) <- 'STATE'
+#' query(wg, 'values', rm.duplicates = TRUE)
+#' @rdname query
+#' @aliases query,webdata-method  
 setMethod(f = "query",signature("webdata",'character'),
           definition = function(.Object, field, ...){
             field <- match.arg(field, c('variables','times'))
@@ -52,7 +52,7 @@ setMethod(f = "query",signature("character",'missing'),
           }
 )
 
-#' @importFrom httr content POST content_type_xml
+#' @importFrom httr  POST content_type_xml
 webdata_query <- function(csw_url = 'https://www.sciencebase.gov/catalog/item/54dd2326e4b08de9379b2fb1/csw'){
   request = '<csw:GetRecords xmlns:csw="http://www.opengis.net/cat/csw/2.0.2" service="CSW" version="2.0.2" resultType="results" outputSchema="http://www.isotc211.org/2005/gmd" maxRecords="1000">
     <csw:Query typeNames="csw:Record">
@@ -63,7 +63,7 @@ webdata_query <- function(csw_url = 'https://www.sciencebase.gov/catalog/item/54
   parentxpath <- paste0(xpath,paste(rep('/parent::node()[1]',6), collapse='')) #/parent::node()[1]
   namespaces = c('srv','gmd','gco')
  
-  response <- content(httr::POST(url = csw_url, body = request, content_type_xml()))
+  response <- gcontent(httr::POST(url = csw_url, body = request, content_type_xml()))
   urls <- lapply(getNodeSet(response, xpath, namespaces = namespaces), xmlValue)
   abstracts = sapply(getNodeSet(response, paste0(parentxpath,'/gmd:abstract'), namespaces = namespaces), xmlValue)
   titles = sapply(getNodeSet(response, paste0(parentxpath,'/gmd:citation/gmd:CI_Citation/gmd:title/gco:CharacterString'), namespaces = namespaces), xmlValue)
