@@ -8,7 +8,7 @@ setMethod(f = "query",signature("webprocess",'character'),
             } else {
               stop('field ', field, ' not supported.')
             }
-            input_list[['xml']] <- content(GET(url))
+            input_list[['xml']] <- gcontent(GET(url))
             values <- do.call(paste0('parseXML',field), input_list)
             return(values)
           })
